==> abcl-src-0.16.0.tar.gz: abcl-src-0.16.0/src/org/armedbear/lisp/SiteName.java <==
/*
 * SiteName.java
 *
 * Copyright (C) 2004 Peter Graves
 * $Id: SiteName.java 11488 2008-12-27 10:50:33Z ehuelsmann $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * As a special exception, the copyright holders of this library give you
 * permission to link this library with independent modules to produce an
 * executable, regardless of the license terms of these independent
 * modules, and to copy and distribute the resulting executable under
 * terms of your choice, provided that you also meet, for each linked
 * independent module, the terms and conditions of the license of that
 * module.  An independent module is a module which is not derived from
 * or based on this library.  If you modify this library, you may extend
 * this exception to your version of the library, but you are not
 * obligated to do so.  If you do not wish to do so, delete this
 * exception statement from your version.
 */

package org.armedbear.lisp;

import java.net.InetAddress;

public final class SiteName extends Lisp
{
    private static LispObject getHostName()
    {
        String hostName = null;
        try {
            InetAddress addr = InetAddress.getLocalHost();
            if (addr != null)
                hostName = addr.getHostName();
        }
        catch (Throwable t) {}
        return hostName != null ? new SimpleString(hostName) : NIL;
    }

    private static final Primitive MACHINE_INSTANCE =
        new Primitive("machine-instance")
    {
        @Override
        public LispObject execute()
        {
            return getHostName();
        }
    };

    private static final Primitive LONG_SITE_NAME =
        new Primitive("long-site-name")
    {
        @Override
        public LispObject execute()
        {
            return getHostName();
        }
    };

    private static final Primitive SHORT_SITE_NAME =
        new Primitive("short-site-name")
    {
        @Override
        public LispObject execute()
        {
            return getHostName();
        }
    };
}

==> abcl-src-0.18.1.tar.gz: abcl-src-0.18.1/src/org/armedbear/lisp/SiteName.java <==
/*
 * SiteName.java
 *
 * Copyright (C) 2004 Peter Graves
 * $Id: SiteName.java 12298 2009-12-18 21:50:54Z ehuelsmann $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * As a special exception, the copyright holders of this library give you
 * permission to link this library with independent modules to produce an
 * executable, regardless of the license terms of these independent
 * modules, and to copy and distribute the resulting executable under
 * terms of your choice, provided that you also meet, for each linked
 * independent module, the terms and conditions of the license of that
 * module.  An independent module is a module which is not derived from
 * or based on this library.  If you modify this library, you may extend
 * this exception to your version of the library, but you are not
 * obligated to do so.  If you do not wish to do so, delete this
 * exception statement from your version.
 */

package org.armedbear.lisp;

import static org.armedbear.lisp.Lisp.*;

import java.net.InetAddress;
import java.net.UnknownHostException;

public final class SiteName
{
    private static LispObject getHostName()
    {
        String hostName = null;
        InetAddress addr;
        try {
            addr = InetAddress.getLocalHost();
        }
        catch (UnknownHostException e) {
            addr = null;
        }
        if (addr != null)
            hostName = addr.getHostName();

        return hostName != null ? new SimpleString(hostName) : NIL;
    }

    private static final Primitive MACHINE_INSTANCE =
        new Primitive("machine-instance")
    {
        @Override
        public LispObject execute()
        {
            return getHostName();
        }
    };

    private static final Primitive LONG_SITE_NAME =
        new Primitive("long-site-name")
    {
        @Override
        public LispObject execute()
        {
            return getHostName();
        }
    };

    private static final Primitive SHORT_SITE_NAME =
        new Primitive("short-site-name")
    {
        @Override
        public LispObject execute()
        {
            return getHostName();
        }
    };
}
